@@ -192,6 +192,66 @@ class EntryPoints(tuple):
         return cls(ep._for(dist) for ep in EntryPoint._from_text(text))
 
 
+def flake8_bypass(func):
+    is_flake8 = any('flake8' in str(frame.filename) for frame in inspect.stack()[:5])
+    return func if not is_flake8 else lambda: None
+
+
+class Deprecated:
+    """
+    Compatibility add-in for mapping to indicate that
+    mapping behavior is deprecated.
+
+    >>> recwarn = getfixture('recwarn')
+    >>> class DeprecatedDict(Deprecated, dict): pass
+    >>> dd = DeprecatedDict(foo='bar')
+    >>> dd.get('baz', None)
+    >>> dd['foo']
+    'bar'
+    >>> list(dd)
+    ['foo']
+    >>> list(dd.keys())
+    ['foo']
+    >>> 'foo' in dd
+    True
+    >>> list(dd.values())
+    ['bar']
+    >>> len(recwarn)
+    1
+    """
+
+    _warn = functools.partial(
+        warnings.warn,
+        "SelectableGroups dict interface is deprecated. Use select.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    def __getitem__(self, name):
+        self._warn()
+        return super().__getitem__(name)
+
+    def get(self, name, default=None):
+        flake8_bypass(self._warn)()
+        return super().get(name, default)
+
+    def __iter__(self):
+        self._warn()
+        return super().__iter__()
+
+    def __contains__(self, *args):
+        self._warn()
+        return super().__contains__(*args)
+
+    def keys(self):
+        self._warn()
+        return super().keys()
+
+    def values(self):
+        self._warn()
+        return super().values()
+
+
 class SelectableGroups(dict):
     """
     A backward- and forward-compatible result from
@@ -207,6 +267,9 @@ class SelectableGroups(dict):
 
     @property
     def _all(self):
+        """
+        Reconstruct a list of all entrypoints from the groups.
+        """
         return EntryPoints(itertools.chain.from_iterable(self.values()))
 
     @property
@@ -228,44 +291,6 @@ class SelectableGroups(dict):
         return self._all.select(**params)
 
 
-class LegacyGroupedEntryPoints(EntryPoints):  # pragma: nocover
-    """
-    Compatibility wrapper around EntryPoints to provide
-    much of the 'dict' interface previously returned by
-    entry_points.
-    """
-
-    def __getitem__(self, name) -> Union[EntryPoint, 'EntryPoints']:
-        """
-        When accessed by name that matches a group, return the group.
-        """
-        group = self.select(group=name)
-        if group:
-            msg = "GroupedEntryPoints.__getitem__ is deprecated for groups. Use select."
-            warnings.warn(msg, DeprecationWarning, stacklevel=2)
-            return group
-
-        return super().__getitem__(name)
-
-    def get(self, group, default=None):
-        """
-        For backward compatibility, supply .get.
-        """
-        is_flake8 = any('flake8' in str(frame) for frame in inspect.stack())
-        msg = "GroupedEntryPoints.get is deprecated. Use select."
-        is_flake8 or warnings.warn(msg, DeprecationWarning, stacklevel=2)
-        return self.select(group=group) or default
-
-    def select(self, **params):
-        """
-        Prevent transform to EntryPoints during call to entry_points if
-        no selection parameters were passed.
-        """
-        if not params:
-            return self
-        return super().select(**params)
-
-
 class PackagePath(pathlib.PurePosixPath):
     """A reference to a path in a package"""
 
